@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our @ISA = qw(Tie::StdHash);
 use Carp 'croak';
@@ -25,7 +25,7 @@ sub DESTROY {}
 sub UNTIE   {}
 
 sub _parse_usage {
-    my $path = shift;
+    my $path = shift || '.';
     if ((!-e $DU_BIN || !-f $DU_BIN) && $] >= 5.008) { 
         require File::Which;
 	$DU_BIN = File::Which::which('du');
@@ -53,20 +53,21 @@ Tie::DiskUsage - tie disk-usage to an hash.
 
  require Tie::DiskUsage;
 
- tie %usage, 'Tie::DiskUsage', '/etc', '-h';
- 
- print $usage{'/etc'};
+ tie %usage, 'Tie::DiskUsage', '/var', '-h';
+
+ print $usage{'/var/log'};
 
 =head1 DESCRIPTION
 
 Tie::DiskUsage ties the disk-usage, which is gathered
-from the output of C<du>, to an hash. The mandatory parameter 
-consists of the path to perform the du-command on e.g. F</etc>, 
-optional arguments to C<du> may be passed subsequently.
+from the output of C<du>, to an hash. If the path to perform 
+the du-command on e.g. F</etc> is being omitted, the current working 
+directory will be assumed; optional arguments to C<du> may be 
+passed subsequently.
 
 By default the location of the du-command is to be
-assumed in F</usr/bin/du>; if C<du> cannot be found there, 
-C<File::Which> will attempt to gather its former location.
+assumed in F</usr/bin/du>; if C<du> cannot be found to exist
+there, C<File::Which> will attempt to gather its former location.
 
 =head1 SEE ALSO
 
